@@ -38,7 +38,6 @@
 AutoFill::AutoFill(QObject* parent)
     : QObject(parent)
     , m_manager(new PasswordManager(this))
-    , m_isStoring(false)
 {
     loadSettings();
 
@@ -62,6 +61,7 @@ void AutoFill::loadSettings()
     Settings settings;
     settings.beginGroup("Web-Browser-Settings");
     m_isStoring = settings.value("SavePasswordsOnSites", true).toBool();
+    m_isAutoComplete = settings.value("AutoCompletePasswords", true).toBool();
     settings.endGroup();
 }
 
@@ -71,7 +71,7 @@ bool AutoFill::isStored(const QUrl &url)
         return false;
     }
 
-    return !m_manager->getEntries(url).isEmpty();
+    return !m_manager->getUsernames(url).isEmpty();
 }
 
 bool AutoFill::isStoringEnabled(const QUrl &url)
@@ -219,21 +219,30 @@ void AutoFill::saveForm(WebPage *page, const QUrl &frameUrl, const PageFormData
 }
 
 // Returns all saved passwords on this page
-QVector<PasswordEntry> AutoFill::completePage(WebPage *page, const QUrl &frameUrl)
+QStringList AutoFill::completePage(WebPage *page, const QUrl &frameUrl)
 {
-    QVector<PasswordEntry> list;
+    QStringList usernames;
 
     if (!page || !isStored(frameUrl))
-        return list;
+        return usernames;
 
-    list = getFormData(frameUrl);
+    if (!m_isAutoComplete) {
+        return m_manager->getUsernames(frameUrl);
+    }
 
-    if (!list.isEmpty()) {
-        const PasswordEntry entry = list.at(0);
+    const auto entries = getFormData(frameUrl);
+
+    if (!entries.isEmpty()) {
+        PasswordEntry entry = entries.at(0);
+        updateLastUsed(entry);
         page->runJavaScript(Scripts::completeFormData(entry.data), WebPage::SafeJsWorld);
     }
 
-    return list;
+    usernames.reserve(entries.size());
+    for (const PasswordEntry &entry : entries) {
+        usernames.append(entry.username);
+    }
+    return usernames;
 }
 
 QByteArray AutoFill::exportPasswords()
