@@ -156,6 +156,11 @@ void LocationCompleterRefreshJob::completeFromHistory()
         foreach (BookmarkItem* bookmark, bookmarks) {
             Q_ASSERT(bookmark->isUrl());
 
+            // Keyword bookmark replaces visit/search item
+            if (bookmark->keyword() == m_searchString) {
+                continue;
+            }
+
             QStandardItem* item = new QStandardItem();
             item->setText(bookmark->url().toEncoded());
             item->setData(-1, LocationCompleterModel::IdRole);
@@ -214,6 +219,7 @@ void LocationCompleterRefreshJob::completeMostVisited()
         item->setData(query.value(0), LocationCompleterModel::IdRole);
         item->setData(query.value(2), LocationCompleterModel::TitleRole);
         item->setData(url, LocationCompleterModel::UrlRole);
+        item->setData(true, LocationCompleterModel::HistoryRole);
 
         m_items.append(item);
     }
