@@ -75,8 +75,9 @@ LocationBar::LocationBar(BrowserWindow* window)
     m_completer->setLocationBar(this);
     connect(m_completer, SIGNAL(showCompletion(QString,bool)), this, SLOT(showCompletion(QString,bool)));
     connect(m_completer, SIGNAL(showDomainCompletion(QString)), this, SLOT(showDomainCompletion(QString)));
-    connect(m_completer, SIGNAL(loadCompletion()), this, SLOT(requestLoadUrl()));
     connect(m_completer, SIGNAL(clearCompletion()), this, SLOT(clearCompletion()));
+    connect(m_completer, &LocationCompleter::loadRequested, this, &LocationBar::loadRequest);
+    connect(m_completer, &LocationCompleter::popupClosed, this, &LocationBar::updateSiteIcon);
 
     m_domainCompleterModel = new QStringListModel(this);
     QCompleter* domainCompleter = new QCompleter(this);
@@ -129,7 +130,6 @@ void LocationBar::setWebView(TabbedWebView* view)
     connect(m_webView, SIGNAL(loadFinished(bool)), SLOT(loadFinished()));
     connect(m_webView, SIGNAL(urlChanged(QUrl)), this, SLOT(showUrl(QUrl)));
     connect(m_webView, SIGNAL(privacyChanged(bool)), this, SLOT(setPrivacyState(bool)));
-    connect(m_webView, &TabbedWebView::iconChanged, this, &LocationBar::updateSiteIcon);
 }
 
 void LocationBar::setText(const QString &text)
@@ -160,6 +160,8 @@ void LocationBar::showCompletion(const QString &completion, bool completeDomain)
     if (completeDomain) {
         completer()->complete();
     }
+
+    updateSiteIcon();
 }
 
 void LocationBar::clearCompletion()
@@ -178,54 +180,6 @@ void LocationBar::showDomainCompletion(const QString &completion)
         completer()->complete();
 }
 
-LoadRequest LocationBar::createLoadRequest() const
-{
-    LoadRequest req;
-
-    const QString &t = text().trimmed();
-
-    // Check for Search Engine shortcut
-    int firstSpacePos = t.indexOf(QLatin1Char(' '));
-    if (firstSpacePos != -1) {
-        const QString shortcut = t.left(firstSpacePos);
-        const QString searchedString = t.mid(firstSpacePos).trimmed();
-
-        SearchEngine en = mApp->searchEnginesManager()->engineForShortcut(shortcut);
-        if (!en.name.isEmpty()) {
-            req = mApp->searchEnginesManager()->searchResult(en, searchedString);
-        }
-    }
-
-    // Check for Bookmark keyword
-    QList<BookmarkItem*> items = mApp->bookmarks()->searchKeyword(t);
-    if (!items.isEmpty()) {
-        BookmarkItem* item = items.at(0);
-        item->updateVisitCount();
-        req.setUrl(item->url());
-    }
-
-    if (!req.isValid()) {
-        // One word needs special handling, because QUrl::fromUserInput
-        // would convert it to QUrl("http://WORD")
-        if (t != QL1S("localhost") && !t.contains(QL1C(' ')) && !t.contains(QL1C('.'))) {
-            req.setUrl(QUrl(t));
-        } else {
-            const QUrl &guessed = QUrl::fromUserInput(t);
-            if (!guessed.isEmpty())
-                req.setUrl(guessed);
-            else
-                req.setUrl(QUrl::fromEncoded(t.toUtf8()));
-        }
-    }
-
-    // Search when creating url failed
-    if (!req.isValid()) {
-        req = mApp->searchEnginesManager()->searchResult(t);
-    }
-
-    return req;
-}
-
 QString LocationBar::convertUrlToText(const QUrl &url)
 {
     // It was most probably entered by user, so don't urlencode it
@@ -245,7 +199,7 @@ QString LocationBar::convertUrlToText(const QUrl &url)
 SearchEnginesManager::Engine LocationBar::searchEngine()
 {
     if (!qzSettings->searchFromAddressBar) {
-        return SearchEnginesManager::Engine();
+        return SearchEngine();
     } else if (qzSettings->searchWithDefaultEngine) {
         return mApp->searchEnginesManager()->defaultEngine();
     } else {
@@ -253,6 +207,85 @@ SearchEnginesManager::Engine LocationBar::searchEngine()
     }
 }
 
+LocationBar::LoadAction LocationBar::loadAction(const QString &text)
+{
+    LoadAction action;
+
+    const QString &t = text.trimmed();
+
+    if (t.isEmpty()) {
+        return action;
+    }
+
+    // Check for Search Engine shortcut
+    const int firstSpacePos = t.indexOf(QLatin1Char(' '));
+    if (qzSettings->searchFromAddressBar && firstSpacePos != -1) {
+        const QString shortcut = t.left(firstSpacePos);
+        const QString searchedString = t.mid(firstSpacePos).trimmed();
+
+        SearchEngine en = mApp->searchEnginesManager()->engineForShortcut(shortcut);
+        if (en.isValid()) {
+            action.type = LoadAction::Search;
+            action.searchEngine = en;
+            action.loadRequest = mApp->searchEnginesManager()->searchResult(en, searchedString);
+            return action;
+        }
+    }
+
+    // Check for Bookmark keyword
+    const QList<BookmarkItem*> items = mApp->bookmarks()->searchKeyword(t);
+    if (!items.isEmpty()) {
+        BookmarkItem* item = items.at(0);
+        action.type = LoadAction::Bookmark;
+        action.bookmark = item;
+        action.loadRequest.setUrl(item->url());
+        return action;
+    }
+
+    if (!qzSettings->searchFromAddressBar) {
+        action.type = LoadAction::Url;
+        action.loadRequest = QUrl(t);
+        return action;
+    }
+
+    // Check for one word search
+    if (t != QL1S("localhost")
+            && !QzTools::containsSpace(t)
+            && !t.contains(QL1C('.'))
+            && !t.contains(QL1C(':'))
+            && !t.contains(QL1C('/'))
+       ) {
+        action.type = LoadAction::Search;
+        action.searchEngine = searchEngine();
+        action.loadRequest = mApp->searchEnginesManager()->searchResult(searchEngine(), t);
+        return action;
+    }
+
+    // Otherwise load as url
+    const QUrl &guessedUrl = QUrl::fromUserInput(t);
+    if (guessedUrl.isValid()) {
+        // Only allow spaces in query
+        if (!QzTools::containsSpace(guessedUrl.toString(QUrl::RemoveQuery))) {
+            // Only allow whitelisted schemes
+            const QSet<QString> whitelistedSchemes = {
+                QSL("http"), QSL("https"), QSL("ftp"), QSL("file"),
+                QSL("data"), QSL("about"), QSL("qupzilla")
+            };
+            if (whitelistedSchemes.contains(guessedUrl.scheme())) {
+                action.type = LoadAction::Url;
+                action.loadRequest = guessedUrl;
+                return action;
+            }
+        }
+    }
+
+    // Search when creating url failed
+    action.type = LoadAction::Search;
+    action.searchEngine = searchEngine();
+    action.loadRequest = mApp->searchEnginesManager()->searchResult(searchEngine(), t);
+    return action;
+}
+
 void LocationBar::refreshTextFormat()
 {
     if (!m_webView) {
@@ -294,17 +327,7 @@ void LocationBar::refreshTextFormat()
 
 void LocationBar::requestLoadUrl()
 {
-    const LoadRequest req = createLoadRequest();
-    const QString urlString = convertUrlToText(req.url());
-
-    m_completer->closePopup();
-    m_webView->setFocus();
-
-    if (urlString != text()) {
-        setText(urlString);
-    }
-
-    m_webView->userLoadAction(req);
+    loadRequest(loadAction(text()).loadRequest);
 }
 
 void LocationBar::textEdited(const QString &text)
@@ -314,6 +337,7 @@ void LocationBar::textEdited(const QString &text)
 
     if (!text.isEmpty()) {
         m_completer->complete(text);
+        m_siteIcon->setIcon(QIcon::fromTheme(QSL("edit-find"), QIcon(QSL(":icons/menu/search-icon.svg"))));
     }
     else {
         m_completer->closePopup();
@@ -362,12 +386,31 @@ void LocationBar::showUrl(const QUrl &url)
     m_bookmarkIcon->checkBookmark(url);
 }
 
+void LocationBar::loadRequest(const LoadRequest &request)
+{
+    const QString urlString = convertUrlToText(request.url());
+
+    m_completer->closePopup();
+    m_webView->setFocus();
+
+    if (urlString != text()) {
+        setText(urlString);
+    }
+
+    m_webView->userLoadAction(request);
+}
+
 void LocationBar::updateSiteIcon()
 {
-    QIcon icon = m_webView ? m_webView->icon() : IconProvider::emptyWebIcon();
-    if (m_webView && m_webView->url().scheme() == QL1S("https"))
-        icon = QIcon::fromTheme(QSL("document-encrypted"), icon);
-    m_siteIcon->setIcon(QIcon(icon.pixmap(16)));
+    if (m_completer->isVisible()) {
+        m_siteIcon->setIcon(QIcon::fromTheme(QSL("edit-find"), QIcon(QSL(":icons/menu/search-icon.svg"))));
+    } else {
+        QIcon icon = IconProvider::emptyWebIcon();
+        if (property("secured").toBool()) {
+            icon = QIcon::fromTheme(QSL("document-encrypted"), icon);
+        }
+        m_siteIcon->setIcon(QIcon(icon.pixmap(16)));
+    }
 }
 
 void LocationBar::setPrivacyState(bool state)
@@ -379,6 +422,8 @@ void LocationBar::setPrivacyState(bool state)
     setProperty("secured", QVariant(state));
     style()->unpolish(this);
     style()->polish(this);
+
+    updateSiteIcon();
 }
 
 void LocationBar::pasteAndGo()
@@ -526,7 +571,7 @@ void LocationBar::keyPressEvent(QKeyEvent* event)
 
         case Qt::AltModifier:
             m_completer->closePopup();
-            m_window->tabWidget()->addView(createLoadRequest());
+            m_window->tabWidget()->addView(loadAction(text()).loadRequest);
             m_holdingAlt = false;
             break;
 
@@ -585,12 +630,10 @@ void LocationBar::loadFinished()
 
     WebPage* page = qobject_cast<WebPage*>(m_webView->page());
 
-    if (page && page->hasMultipleUsernames()) {
-        m_autofillIcon->setFormData(page->autoFillData());
+    if (page && !page->autoFillUsernames().isEmpty()) {
+        m_autofillIcon->setUsernames(page->autoFillUsernames());
         m_autofillIcon->show();
     }
-
-    updateSiteIcon();
 }
 
 void LocationBar::loadSettings()
