@@ -97,7 +97,6 @@ Preferences::Preferences(BrowserWindow* window)
     , m_window(window)
     , m_autoFillManager(0)
     , m_pluginsList(0)
-    , m_autoFillEnabled(false)
 {
     setAttribute(Qt::WA_DeleteOnClose);
     ui->setupUi(this);
@@ -293,9 +292,7 @@ Preferences::Preferences(BrowserWindow* window)
 
     //PASSWORD MANAGER
     ui->allowPassManager->setChecked(settings.value("SavePasswordsOnSites", true).toBool());
-    connect(ui->allowPassManager, SIGNAL(toggled(bool)), this, SLOT(showPassManager(bool)));
-
-    showPassManager(ui->allowPassManager->isChecked());
+    ui->autoCompletePasswords->setChecked(settings.value("AutoCompletePasswords", true).toBool());
 
     //PRIVACY
     //Web storage
@@ -581,7 +578,6 @@ void Preferences::showStackedPage(QListWidgetItem* item)
     if (index == 7 && !m_autoFillManager) {
         m_autoFillManager = new AutoFillManager(this);
         ui->autoFillFrame->addWidget(m_autoFillManager);
-        m_autoFillManager->setVisible(m_autoFillEnabled);
     }
 }
 
@@ -767,16 +763,6 @@ void Preferences::changeCachePathClicked()
     ui->cachePath->setText(path);
 }
 
-void Preferences::showPassManager(bool state)
-{
-    if (m_autoFillManager) {
-        m_autoFillManager->setVisible(state);
-    }
-    else {
-        m_autoFillEnabled = state;
-    }
-}
-
 void Preferences::buttonClicked(QAbstractButton* button)
 {
     switch (ui->buttonBox->buttonRole(button)) {
@@ -983,6 +969,7 @@ void Preferences::saveSettings()
 
     //PASSWORD MANAGER
     settings.setValue("SavePasswordsOnSites", ui->allowPassManager->isChecked());
+    settings.setValue("AutoCompletePasswords", ui->autoCompletePasswords->isChecked());
 
     //PRIVACY
     //Web storage
