@@ -1,7 +1,7 @@
 /* ============================================================
-* QupZilla - WebKit based browser
+* QupZilla - Qt web browser
 * Copyright (C) 2013-2014 S. Razi Alavizadeh <s.r.alavizadeh@gmail.com>
-* Copyright (C) 2014-2016 David Rosca <nowrep@gmail.com>
+* Copyright (C) 2014-2018 David Rosca <nowrep@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
 #define COMBOTABBAR_H
 
 #include "qzcommon.h"
+#include "wheelhelper.h"
 
 #include <QTabBar>
 #include <QScrollBar>
@@ -51,6 +52,11 @@ public:
         ExtraReservedWidth
     };
 
+    enum DropIndicatorPosition {
+        BeforeTab,
+        AfterTab
+    };
+
     explicit ComboTabBar(QWidget* parent = 0);
 
     int addTab(const QString &text);
@@ -69,6 +75,8 @@ public:
     void setTabTextColor(int index, const QColor &color);
 
     QRect tabRect(int index) const;
+    QRect draggedTabRect() const;
+    QPixmap tabPixmap(int index) const;
 
     // Returns tab index at pos, or -1
     int tabAt(const QPoint &pos) const;
@@ -116,6 +124,7 @@ public:
     bool isPinned(int index) const;
     void setMaxVisiblePinnedTab(int max);
 
+    void setFocusPolicy(Qt::FocusPolicy policy);
     void setObjectName(const QString &name);
     void setMouseTracking(bool enable);
 
@@ -134,6 +143,9 @@ public:
     bool usesScrollButtons() const;
     void setUsesScrollButtons(bool useButtons);
 
+    void showDropIndicator(int index, DropIndicatorPosition position);
+    void clearDropIndicator();
+
     bool isDragInProgress() const;
     bool isScrollInProgress() const;
     bool isMainBarOverflowed() const;
@@ -143,6 +155,9 @@ public:
     // Add widget to the left/right corner
     void addCornerWidget(QWidget* widget, Qt::Corner corner);
 
+    // Duration of tab slide animation when releasing dragged tab
+    static int slideAnimationDuration();
+
 public slots:
     void setUpLayout();
     void ensureVisible(int index = -1, int xmargin = -1);
@@ -183,6 +198,7 @@ private:
     TabBarHelper* localTabBar(int index = -1) const;
 
     int toLocalIndex(int globalIndex) const;
+    QRect mapFromLocalTabRect(const QRect &rect, QWidget *tabBar) const;
     void updatePinnedTabBarVisibility();
 
     QHBoxLayout* m_mainLayout;
@@ -203,6 +219,8 @@ private:
     bool m_usesScrollButtons;
     bool m_blockCurrentChangedSignal;
 
+    WheelHelper m_wheelHelper;
+
     friend class TabBarHelper;
     friend class TabStackedWidget;
 };
@@ -210,15 +228,26 @@ private:
 class QUPZILLA_EXPORT TabBarHelper : public QTabBar
 {
     Q_OBJECT
+    Q_PROPERTY(int tabPadding READ tabPadding WRITE setTabPadding)
+    Q_PROPERTY(QColor baseColor READ baseColor WRITE setBaseColor)
 
 public:
     explicit TabBarHelper(bool isPinnedTabBar, ComboTabBar* comboTabBar);
 
+    int tabPadding() const;
+    void setTabPadding(int padding);
+
+    QColor baseColor() const;
+    void setBaseColor(const QColor &color);
+
     void setTabButton(int index, QTabBar::ButtonPosition position, QWidget* widget);
 
     QSize tabSizeHint(int index) const;
     QSize baseClassTabSizeHint(int index) const;
 
+    QRect draggedTabRect() const;
+    QPixmap tabPixmap(int index) const;
+
     bool isActiveTabBar();
     void setActiveTabBar(bool activate);
 
@@ -227,6 +256,9 @@ public:
     void setScrollArea(QScrollArea* scrollArea);
     void useFastTabSizeHint(bool enabled);
 
+    void showDropIndicator(int index, ComboTabBar::DropIndicatorPosition position);
+    void clearDropIndicator();
+
     bool isDisplayedOnViewPort(int globalLeft, int globalRight);
     bool isDragInProgress() const;
 
@@ -235,30 +267,30 @@ public:
 public slots:
     void setCurrentIndex(int index);
 
-private slots:
-    void resetDragState();
-    void tabWasMoved(int from, int to);
-
 private:
     bool event(QEvent* ev);
     void paintEvent(QPaintEvent* event);
     void mousePressEvent(QMouseEvent* event);
+    void mouseMoveEvent(QMouseEvent *event);
     void mouseReleaseEvent(QMouseEvent* event);
 
+    int dragOffset(QStyleOptionTab *option, int tabIndex) const;
     void initStyleOption(QStyleOptionTab* option, int tabIndex) const;
 
-    void tabInserted(int index);
-    void tabRemoved(int index);
-
     ComboTabBar* m_comboTabBar;
     QScrollArea* m_scrollArea;
 
+    int m_tabPadding = -1;
+    QColor m_baseColor;
     int m_pressedIndex;
-    int m_pressedGlobalX;
     bool m_dragInProgress;
+    QPoint m_dragStartPosition;
+    class QMovableTabWidget *m_movingTab = nullptr;
     bool m_activeTabBar;
     bool m_isPinnedTabBar;
     bool m_useFastTabSizeHint;
+    int m_dropIndicatorIndex = -1;
+    ComboTabBar::DropIndicatorPosition m_dropIndicatorPosition;
 };
 
 class QUPZILLA_EXPORT TabScrollBar : public QScrollBar
