@@ -17,12 +17,15 @@
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * ============================================================ */
 #import <AppKit/AppKit.h>
+#import <Availability.h>
 
 // code taken from: https://www.mail-archive.com/interest@qt-project.org/msg23593.html
 // Disables auto window tabbing where supported, otherwise a no-op.
 void disableWindowTabbing()
 {
+#if __MAC_OS_X_VERSION_MAX_ALLOWED >= 101200
     if ([NSWindow respondsToSelector:@selector(allowsAutomaticWindowTabbing)]) {
         NSWindow.allowsAutomaticWindowTabbing = NO;
     }
+#endif
 }
