@@ -1,6 +1,6 @@
 /* ============================================================
-* QupZilla - WebKit based browser
-* Copyright (C) 2015-2016 David Rosca <nowrep@gmail.com>
+* QupZilla - Qt web browser
+* Copyright (C) 2015-2018 David Rosca <nowrep@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -28,8 +28,9 @@ class QWebEngineView;
 class QUPZILLA_EXPORT Scripts
 {
 public:
-    static QString setupWebChannel();
+    static QString setupWebChannel(quint32 worldId);
     static QString setupFormObserver();
+    static QString setupWindowObject();
 
     static QString setCss(const QString &css);
     static QString sendPostData(const QUrl &url, const QByteArray &data);
@@ -37,7 +38,7 @@ public:
     static QString getOpenSearchLinks();
     static QString getAllImages();
     static QString getAllMetaAttributes();
-    static QString getFormData(const QPoint &pos);
+    static QString getFormData(const QPointF &pos);
 };
 
 #endif // SCRIPTS_H
