@@ -41,6 +41,7 @@
 #include "ui_jsconfirm.h"
 #include "ui_jsalert.h"
 #include "ui_jsprompt.h"
+#include "passwordmanager.h"
 
 #include <iostream>
 
@@ -240,7 +241,7 @@ void WebPage::finished()
     }
 
     // AutoFill
-    m_passwordEntries = mApp->autoFill()->completePage(this, url());
+    m_autoFillUsernames = mApp->autoFill()->completePage(this, url());
 }
 
 void WebPage::watchedFileChanged(const QString &file)
@@ -401,12 +402,15 @@ bool WebPage::acceptNavigationRequest(const QUrl &url, QWebEnginePage::Navigatio
 
     const bool result = QWebEnginePage::acceptNavigationRequest(url, type, isMainFrame);
 
-    if (result && isMainFrame) {
-        const bool isWeb = url.scheme() == QL1S("http") || url.scheme() == QL1S("https") || url.scheme() == QL1S("file");
-        const bool globalJsEnabled = mApp->webSettings()->testAttribute(QWebEngineSettings::JavascriptEnabled);
-        settings()->setAttribute(QWebEngineSettings::JavascriptEnabled, isWeb ? globalJsEnabled : true);
+    if (result) {
+        if (isMainFrame) {
+            const bool isWeb = url.scheme() == QL1S("http") || url.scheme() == QL1S("https") || url.scheme() == QL1S("file");
+            const bool globalJsEnabled = mApp->webSettings()->testAttribute(QWebEngineSettings::JavascriptEnabled);
+            settings()->setAttribute(QWebEngineSettings::JavascriptEnabled, isWeb ? globalJsEnabled : true);
 
-        setupWebChannelForUrl(url);
+            setupWebChannelForUrl(url);
+        }
+        emit navigationRequestAccepted(url, type, isMainFrame);
     }
 
     return result;
@@ -446,14 +450,9 @@ QStringList WebPage::chooseFiles(QWebEnginePage::FileSelectionMode mode, const Q
     return files;
 }
 
-bool WebPage::hasMultipleUsernames() const
+QStringList WebPage::autoFillUsernames() const
 {
-    return m_passwordEntries.count() > 1;
-}
-
-QVector<PasswordEntry> WebPage::autoFillData() const
-{
-    return m_passwordEntries;
+    return m_autoFillUsernames;
 }
 
 bool WebPage::javaScriptPrompt(const QUrl &securityOrigin, const QString &msg, const QString &defaultValue, QString* result)
@@ -627,7 +626,8 @@ QWebEnginePage* WebPage::createWindow(QWebEnginePage::WebWindowType type)
         // Workaround focus issue when creating tab
         if (pos.testFlag(Qz::NT_SelectedTab)) {
             QPointer<TabbedWebView> pview = view;
-            QTimer::singleShot(0, this, [pview]() {
+            pview->setFocus();
+            QTimer::singleShot(100, this, [pview]() {
                 if (pview && pview->webTab()->isCurrentTab()) {
                     pview->setFocus();
                 }
