@@ -326,6 +326,7 @@ void TabManagerWidget::customContextMenuRequested(const QPoint &pos)
         menu->addAction(QIcon(":/tabmanager/data/tab-detach.png"), tr("&Detach checked tabs"), this, SLOT(processActions()))->setObjectName("detachSelection");
         menu->addAction(QIcon(":/tabmanager/data/tab-bookmark.png"), tr("Book&mark checked tabs"), this, SLOT(processActions()))->setObjectName("bookmarkSelection");
         menu->addAction(QIcon(":/tabmanager/data/tab-close.png"), tr("&Close checked tabs"), this, SLOT(processActions()))->setObjectName("closeSelection");
+        menu->addAction(tr("&Unload checked tabs"), this, SLOT(processActions()))->setObjectName("unloadSelection");
     }
 
     menu->exec(ui->treeWidget->viewport()->mapToGlobal(pos));
@@ -471,12 +472,7 @@ void TabManagerWidget::processActions()
                 continue;
             }
 
-            if (command == "closeSelection") {
-                selectedTabs.insertMulti(mainWindow, webTab);
-            }
-            else if (command == "detachSelection" || command == "bookmarkSelection") {
-                selectedTabs.insertMulti(mainWindow, webTab);
-            }
+            selectedTabs.insertMulti(mainWindow, webTab);
         }
         winItem->setCheckState(0, Qt::Unchecked);
     }
@@ -491,6 +487,9 @@ void TabManagerWidget::processActions()
         else if (command == "bookmarkSelection") {
             bookmarkSelectedTabs(selectedTabs);
         }
+        else if (command == "unloadSelection") {
+            unloadSelectedTabs(selectedTabs);
+        }
     }
 
     m_refreshBlocked = false;
@@ -604,6 +603,22 @@ bool TabManagerWidget::bookmarkSelectedTabs(const QHash<BrowserWindow*, WebTab*>
     return true;
 }
 
+void TabManagerWidget::unloadSelectedTabs(const QHash<BrowserWindow*, WebTab*> &tabsHash)
+{
+    if (tabsHash.isEmpty()) {
+        return;
+    }
+
+    const QList<BrowserWindow*> &windows = tabsHash.uniqueKeys();
+    foreach (BrowserWindow* mainWindow, windows) {
+        QList<WebTab*> tabs = tabsHash.values(mainWindow);
+
+        foreach (WebTab* webTab, tabs) {
+            mainWindow->tabWidget()->unloadTab(webTab->tabIndex());
+        }
+    }
+}
+
 QTreeWidgetItem* TabManagerWidget::groupByDomainName(bool useHostName)
 {
     QTreeWidgetItem* currentTabItem = nullptr;
