@@ -16,9 +16,11 @@
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * ============================================================ */
 #include "qztoolstest.h"
+#include "mainapplication.h"
 #include "cookiestest.h"
 #include "adblocktest.h"
 #include "updatertest.h"
+#include "locationbartest.h"
 #include "passwordbackendtest.h"
 
 #include <QtTest/QtTest>
@@ -32,24 +34,16 @@
 
 int main(int argc, char *argv[])
 {
-    QApplication app(argc, argv);
-    QTEST_DISABLE_KEYPAD_NAVIGATION;
+    MainApplication::setTestModeEnabled(true);
+    MainApplication app(argc, argv);
 
     RUN_TEST(QzToolsTest)
-//    RUN_TEST(CookiesTest)
+    RUN_TEST(CookiesTest)
     RUN_TEST(AdBlockTest)
     RUN_TEST(UpdaterTest)
-
+    RUN_TEST(LocationBarTest)
     RUN_TEST(DatabasePasswordBackendTest)
     RUN_TEST(DatabaseEncryptedPasswordBackendTest)
 
-#ifdef HAVE_KDE_PASSWORDS_PLUGIN
-    RUN_TEST(KWalletPasswordBackendTest)
-#endif
-
-#ifdef HAVE_GNOME_PASSWORDS_PLUGIN
-    RUN_TEST(GnomeKeyringPasswordBackendTest)
-#endif
-
     return 0;
 }
