@@ -271,49 +271,3 @@ void DatabaseEncryptedPasswordBackendTest::cleanup()
 {
     QSqlDatabase::removeDatabase(QSqlDatabase::database().databaseName());
 }
-
-#ifdef HAVE_KDE_PASSWORDS_PLUGIN
-// KWalletPassswordBackendTest
-void KWalletPassswordBackendTest::init()
-{
-    QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.freedesktop.DBus"),
-                                                      QStringLiteral("/org/freedesktop/DBus"),
-                                                      QStringLiteral("org.freedesktop.DBus"),
-                                                      QStringLiteral("StartServiceByName"));
-    msg << "org.kde.kwalletd5";
-    msg << quint32(0);
-
-    QDBusMessage reply = QDBusConnection::sessionBus().call(msg);
-    if (reply.arguments().isEmpty() || reply.arguments().first().toInt() != 1)
-        QSKIP("This test requires org.kde.kwalletd5 service.");
-}
-
-void KWalletPasswordBackendTest::reloadBackend()
-{
-    delete m_backend;
-    m_backend = new KWalletPasswordBackend;
-}
-#endif
-
-#ifdef HAVE_GNOME_PASSWORDS_PLUGIN
-// GnomeKeyringPassswordBackendTest
-void GnomeKeyringPasswordBackendTest::init()
-{
-    QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.freedesktop.DBus"),
-                                                      QStringLiteral("/org/freedesktop/DBus"),
-                                                      QStringLiteral("org.freedesktop.DBus"),
-                                                      QStringLiteral("StartServiceByName"));
-    msg << "org.freedesktop.secrets";
-    msg << quint32(0);
-
-    QDBusMessage reply = QDBusConnection::sessionBus().call(msg);
-    if (reply.arguments().isEmpty() || reply.arguments().first().toInt() != 1)
-        QSKIP("This test requires org.freedesktop.secrets service.");
-}
-
-void GnomeKeyringPasswordBackendTest::reloadBackend()
-{
-    delete m_backend;
-    m_backend = new GnomeKeyringPasswordBackend;
-}
-#endif
